@@ -259,7 +259,7 @@ class DataFrame:
         return df
 
     def to_csv(self,path):
-        df = self.to_pandas
+        df = self.to_pandas()
         df.to_csv(path,index = False)
     
     def read_csv(self,path):
